var srcAssets         = 'web/static/src';
var devAssets         = 'web/static/dev';
var prodAssets        = 'web/static/prod';
var appsAssets        = 'web/static/apps';

var srcTemplates      = 'web/templates';
var devTemplates      = 'web/templates_dev';
var prodTemplates     = 'web/templates_prod';

var baseScss          = srcAssets + '/scss/style.scss';
var baseTemplate      = srcTemplates + '/base.html';

var injectTransform = function (filepath, file, index, length, targetFile) {
  if (filepath.slice(-3) === '.js') {
    if (targetFile.path.slice(-3) === '.j2') {
      return '<script src="{{ static("' + filepath + '") }}"></script>';
    }
    else if (targetFile.path.slice(-5) === '.html') {
      return '<script src="\{% static \''+ filepath +'\' %\}"></script>';
    } else {
      return inject.transform.apply(inject.transform, arguments);
    }
  } else if (filepath.slice(-4) === '.css') {
    if (targetFile.path.slice(-3) === '.j2') {
      return '<link rel="stylesheet" href="{{ static("' + filepath + '") }}>';
    } else if (targetFile.path.slice(-5) === '.html') {
      return '<link rel="stylesheet" href="\{% static \'' + filepath + '\' %\}">';
    } else {
      return inject.transform.apply(inject.transform, arguments);
    }
  } else {
    return inject.transform.apply(inject.transform, arguments);
  }
};

module.exports = {
  browsersync: {
    dev: {
      port: 8000,
      ui: {
        port: 8080
      },
      proxy: 'localhost:8010',
      open: false,
      files: [
        devAssets + '/css/*.css',
      ]
    }
  },
  delete: {
    dev: [devAssets, devTemplates],
    prod: [devAssets, prodAssets, prodTemplates]
  },
  deps: {
    src: baseTemplate,
    dest: devTemplates,
    bower: {
      options: {
        name: 'bower',
        addRootSlash: false,
        ignorePath: 'bower_components/',
        transform: injectTransform
      }
    },
    apps: {
      assets: [appsAssets + '/**/*.js', appsAssets + '/**/*.css'],
      options: {
        name: 'apps',
        addRootSlash: false,
        ignorePath: 'web/static/',
        transform: injectTransform
      }
    },
    project: {
      assets: [devAssets + '/**/*.js', devAssets + '/**/*.css'],
      options: {
        addRootSlash: false,
        ignorePath: 'web/static/',
        transform: injectTransform
      }
    }
  },
  inject: {
    src: baseTemplate,
    dest: prodTemplates,
    assets: [prodAssets + '/**/*.js', prodAssets + '/**/*.css'],
    options: {
      addRootSlash: false,
      ignorePath: 'web/static/',
      transform: injectTransform
    }
  },
  optimize: {
    dest: prodAssets,
    mainBowerFiles: {},
    js:{
      src: devAssets + '/**/*.js',
      apps: appsAssets + '/**/*.js',
      fileName: 'bundle.js',
      concat: {},
      uglify: {}
    },
    css: {
      src: devAssets + '/**/*.css',
      apps: appsAssets + '/**/*.css',
      fileName: 'bundle.css',
      concat: {},
      cssnano: {}
    }
  },
  scripts: {
    src: srcAssets + '/js/*.js',
    dest: devAssets + '/js'
  },
  styles: {
    src: baseScss,
    dest: devAssets + '/css/',
    postcss: {
      autoprefixer: {
        browsers: [
          'last 2 versions',
          'safari 5',
          'ie 8',
          'ie 9',
          'opera 12.1',
          'ios 6',
          'android 4'
        ],
        cascade: true
      },
      mqpacker: {}
    },
    inject: {
      options: {
        relative: true
      }
    }
  },
  watch: {
    scss: srcAssets  + '/scss/*.scss',
    js: srcAssets + '/js/*.js',
    html: baseTemplate
  },
};
