# -*- coding: utf-8 -*-
import os
gettext = lambda s: s

SETTINGS_DIR = os.path.abspath(os.path.dirname(__file__))
PROJECT_DIR = os.path.dirname(SETTINGS_DIR)
BASE_DIR = os.path.dirname(PROJECT_DIR)

CMS_ENABLED = False

DEBUG = True

ADMINS = (
    ('Jumbo Team', 'jumbo@thundersystems.it'),
)

MANAGERS = ADMINS

SITE_ID = 1
ROOT_URLCONF = 'jmb_python_module.urls'
WSGI_APPLICATION = 'web.wsgi.application'

# i18N and L10N
TIME_ZONE = 'Europe/Rome'
LANGUAGE_CODE = 'it'
USE_I18N = True
USE_L10N = True
USE_TZ = False
LOCALE_PATHS = (
    os.path.join(PROJECT_DIR, "locale"),
)

# MEDIA AND STATIC
MEDIA_ROOT = os.path.join(BASE_DIR, "media")
MEDIA_URL = '/media/'
STATIC_ROOT = os.path.join(BASE_DIR, "static")
STATIC_URL = '/static/'
STATICFILES_DIRS = [
    os.path.join(PROJECT_DIR, "static"),
]
STATICFILES_FINDERS = [
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
    # 'django.contrib.staticfiles.finders.DefaultStorageFinder',
]

# TEMPLATES
TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [
            os.path.join(PROJECT_DIR, "templates")
        ],
        # 'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.contrib.auth.context_processors.auth',
                'django.core.context_processors.debug',
                'django.core.context_processors.i18n',
                'django.core.context_processors.media',
                'django.core.context_processors.request',
                'django.contrib.messages.context_processors.messages',
                'django.core.context_processors.static'
            ],
            'loaders': [
                'admin_tools.template_loaders.Loader',
                'django.template.loaders.filesystem.Loader',
                'django.template.loaders.app_directories.Loader',
                'django.template.loaders.eggs.Loader'
            ]
        },
    },
]

# MIDDLEWARE
MIDDLEWARE_CLASSES = (
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'jmb.core.middleware.thread_local.ThreadLocals',
)

# Python dotted path to the WSGI application used by Django's runserver.
# WSGI_APPLICATION = 'mycmsproject.wsgi.application'

INSTALLED_APPS = (
    'jmb.jadmin',
    'admin_tools',
    'admin_tools.menu',
    'django.contrib.contenttypes',
    'admin_tools.dashboard',
    'jmb.core',
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    # 'easy_thumbnails',
    'jmb_python_module',
    # admin docs:
    # 'django.contrib.admindocs',
    'autocomplete_light',
    'jmb.filters',
    'jmb.i18n',
    'jmb.l10n',
)


# LOGGERS
# http://docs.djangoproject.com/en/dev/topics/logging for
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'filters': {
        'require_debug_false': {
            '()': 'django.utils.log.RequireDebugFalse'
        }
    },
    'formatters': {
        'verbose': {
            'format': '%(asctime)s %(levelname)s %(module)s %(message)s'
        },
        'simple': {
            'format': '%(message)s %(levelname)s'
        },
    },
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'filters': ['require_debug_false'],
            'class': 'django.utils.log.AdminEmailHandler'
        },
        'console':{
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
            'formatter': 'simple'
        },
        'file': {
            'level': 'DEBUG',
            'class': 'logging.FileHandler',
            'filename': '/var/log/django/jmb-default-pkg.log',
            'formatter': 'verbose'
        },
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },
        'jmb': {
            'handlers': ['file'],
            'propagate': True,
            'level': 'DEBUG',
        }
    }
}


ALLOWED_HOSTS = ['*']
ATOMIC_REQUESTS = True
TEST_RUNNER = 'django.test.runner.DiscoverRunner'

## Patch temporanea per non rompere compatibilita` con passato per patterns
WARNING_RULES = [
    ('jmb.jadmin', ".*Update your urlpatterns.*"),
    ('', ".*OptionParser usage for Django management commands is deprecated.*"),
]

# ADMIN TOOLS SETTINGS
ADMIN_TOOLS_INDEX_DASHBOARD = 'jmb_python_module.dashboard.JumboDashboard'
ADMIN_TOOLS_MENU = 'jmb_python_module.jmenu.JumboMenu'

if CMS_ENABLED:
    from cms_settings import *  # noqa


# hghooks: no-pyflakes no-pep8
