# http://www.28lines.com/?p=8

import os
import re
from setuptools import setup, find_packages
from setuptools.command.test import test


class TestRunner(test):

    def run(self, *args, **kwargs):
        if self.distribution.install_requires:
            self.distribution.fetch_build_eggs(
                self.distribution.install_requires)
        if self.distribution.tests_require:
            self.distribution.fetch_build_eggs(
                self.distribution.tests_require)
        from jmb_python_module.tests.runtests import runtests

        runtests()


def get_data_files(*args, **kwargs):
    EXT_PATTERN = kwargs.get('ext') or '\.(html|js|txt|css|po|mo)'

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name):
            rel_dirpath = re.sub("^" + pkg_name + '/', '', dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'):
                    del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    return data_dict

setup(
    name='jmb-default-pkg',
    version="1.0",
    description='Thux project',
    author='ThunderSystems',
    url='http://hg.thundersystems.it/jmb/jmb-default-pkg',
    author_email='dev@thundersystems.it',
    packages=find_packages(exclude=['tests', 'tests.*']),
    platforms='any',
    zip_safe=False,
    classifiers=[
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Framework :: Django',
        'Framework :: Jumbo',
    ],
    test_suite="jmb_python_module.tests",
    cmdclass={"test": TestRunner},
    install_requires=[
        'setuptools',
        'raven',
        'jmb.core>=0.8.5',
        'jmb.jadmin>=0.9.5',
        'django>=1.9.2',
        'easy_thumbnails>=1.4',
        'django-admin-tools>=0.7.2',
        'django_extensions>=1.6.1',
        'jmb.i18n>=0.6',
        'jmb.l10n>=0.3',
        'jmb.filters>0.2',
        'django-autocomplete-light==2.3.3',
    ],
    package_data=get_data_files('jmb_python_module')
)
